==> ZenTaoPMS-ipd1.2-php7.1.zip: zentaopms/module/extension/lang/zh-tw.php <==
<?php
/**
 * The extension module zh-tw file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2015 禪道軟件（青島）有限公司(ZenTao Software (Qingdao) Co., Ltd. www.cnezsoft.com)
 * @license     ZPL(http://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Chunsheng Wang <chunsheng@cnezsoft.com>
 * @package     extension
 * @version     $Id$
 * @link        http://www.zentao.net
 */
$lang->extension->common           = '插件管理';
$lang->extension->id               = '編號';
$lang->extension->browse           = '瀏覽插件';
$lang->extension->install          = '安裝插件';
$lang->extension->installAuto      = '自動安裝';
$lang->extension->installForce     = '強制安裝';
$lang->extension->uninstall        = '卸載';
$lang->extension->uninstallAction  = '卸載插件';
$lang->extension->activate         = '激活';
$lang->extension->activateAction   = '激活插件';
$lang->extension->deactivate       = '禁用';
$lang->extension->deactivateAction = '禁用插件';
$lang->extension->obtain           = '獲得插件';
$lang->extension->view             = '詳情';
$lang->extension->downloadAB       = '下載';
$lang->extension->upload           = '本地安裝';
$lang->extension->erase            = '清除';
$lang->extension->eraseAction      = '清除插件';
$lang->extension->upgrade          = '升級插件';
$lang->extension->agreeLicense     = '我同意該授權';

$lang->extension->browseAction = '插件列表';

$lang->extension->structure       = '目錄結構';
$lang->extension->structureAction = '目錄結構';
$lang->extension->installed       = '已安裝';
$lang->extension->deactivated     = '被禁用';
$lang->extension->available       = '已下載';

$lang->extension->name             = '插件名稱';
$lang->extension->code             = '代號';
$lang->extension->desc             = '描述';
$lang->extension->type             = '類型';
$lang->extension->dirs             = '安裝目錄';
$lang->extension->files            = '安裝檔案';
$lang->extension->status           = '狀態';
$lang->extension->version          = '版本';
$lang->extension->latest           = '<small>最新版本<strong><a href="%s" target="_blank" class="extension">%s</a></strong>，兼容禪道<a href="https://api.zentao.net/goto.php?item=latest" target="_blank" class="alert-link"><strong>%s</strong></a></small>';
$lang->extension->author           = '作者';
$lang->extension->license          = '授權';
$lang->extension->site             = '官網';
$lang->extension->downloads        = '下載量';
$lang->extension->compatible       = '兼容性';
$lang->extension->grade            = '評分';
$lang->extension->depends          = '依賴';
$lang->extension->expiredDate      = '到期日期';
$lang->extension->zentaoCompatible = '適用版本';
$lang->extension->installedTime    = '安裝時間';
$lang->extension->life             = '終身';

$lang->extension->publicList[0] = '手工下載';
$lang->extension->publicList[1] = '直接下載';

$lang->extension->compatibleList[0] = '未知';
$lang->extension->compatibleList[1] = '兼容';

$lang->extension->obtainOfficial[0] = '第三方';
$lang->extension->obtainOfficial[1] = '官方';

$lang->extension->byDownloads   = '最多下載';
$lang->extension->byAddedTime   = '最新添加';
$lang->extension->byUpdatedTime = '最近更新';
$lang->extension->bySearch      = '搜索';
$lang->extension->byCategory    = '分類瀏覽';

$lang->extension->installFailed            = '%s失敗，錯誤原因如下:';
$lang->extension->uninstallFailed          = '卸載失敗，錯誤原因如下:';
$lang->extension->confirmUninstall         = '卸載插件會刪除或修改相關的資料庫，是否繼續卸載？';
$lang->extension->installFinished          = '恭喜您，插件順利的%s成功！';
$lang->extension->refreshPage              = '刷新頁面';
$lang->extension->uninstallFinished        = '插件已經成功卸載';
$lang->extension->deactivateFinished       = '插件已經成功禁用';
$lang->extension->activateFinished         = '插件已經成功激活';
$lang->extension->eraseFinished            = '插件已經成功清除';
$lang->extension->unremovedFiles           = '有一些檔案或目錄未能刪除，需要手工刪除';
$lang->extension->executeCommands          = '<h3>執行下面的命令來修正這些問題：</h3>';
$lang->extension->successDownloadedPackage = '成功下載插件';
$lang->extension->successCopiedFiles       = '成功拷貝檔案';
$lang->extension->successInstallDB         = '成功安裝資料庫';
$lang->extension->viewInstalled            = '查看已安裝插件';
$lang->extension->viewAvailable            = '查看可安裝插件';
$lang->extension->viewDeactivated          = '查看已禁用插件';
$lang->extension->backDBFile               = '插件相關數據已經備份到 %s 檔案中！';
$lang->extension->noticeOkFile             = "<h5>為了安全起見，系統需要確認您的管理員身份</h5>
    <h5>請登錄禪道所在的伺服器，創建%s檔案。</h5>
    <p>可以執行命令：echo '' > %s</p>
    <p>注意：</p>
    <ol>
    <li>檔案內容為空。</li>
    <li>如果之前檔案存在，刪除之後重新創建。</li>
    </ol>";

$lang->extension->upgradeExt     = '升級';
$lang->extension->installExt     = '安裝';
$lang->extension->upgradeVersion = '（從%s升級到%s）';

$lang->extension->waring = '警告';

$lang->extension->errorOccurs                  = '錯誤：';
$lang->extension->errorGetModules              = '從www.zentao.net獲得插件分類失敗。可能是因為網絡方面的原因，請檢查後重新刷新頁面。';
$lang->extension->errorGetExtensions           = '從www.zentao.net獲得插件失敗。可能是因為網絡方面的原因，您可以到 <a href="https://www.zentao.net/extension/" target="_blank" class="alert-link">www.zentao.net</a> 手工下載插件，然後上傳安裝。';
$lang->extension->errorDownloadPathNotFound    = '插件下載存儲路徑<strong>%s</strong>不存在。<br />linux下面請執行命令：<strong>mkdir -p %s</strong>來修正。';
$lang->extension->errorDownloadPathNotWritable = '插件下載存儲路徑<strong>%s</strong>不可寫。<br />linux下面請執行命令：<strong>sudo chmod 777 %s</strong>來修正。';
$lang->extension->errorPackageFileExists       = '下載路徑已經有一個名為的<strong>%s</strong>附件。<h5>重新%s，<a href="%s" class="alert-link">請點擊此連結</a></h5>';
$lang->extension->errorDownloadFailed          = '下載失敗，請重新下載。如果多次重試還不行，請嘗試手工下載，然後通過上傳功能上傳。';
$lang->extension->errorMd5Checking             = '下載檔案不完整，請重新下載。如果多次重試還不行，請嘗試手工下載，然後通過上傳功能上傳。';
$lang->extension->errorCheckIncompatible       = '該插件與禪道版本不兼容，%s後可能無法使用。<h5>您可以選擇 <a href="%s" class="btn btn-sm">強制%s</a> 或者 <a href="#" onclick=parent.location.href="%s" class="btn btn-sm">取消</a></h5>';
$lang->extension->errorFileConflicted          = '有以下檔案衝突：<br />%s <h5>您可以選擇 <a href="%s" class="btn btn-sm">覆蓋</a> 或者 <a href="#" onclick=parent.location.href="%s" class="btn btn-sm">取消</a></h5>';
$lang->extension->errorPackageNotFound         = '包檔案 <strong>%s </strong>沒有找到，可能是因為自動下載失敗。您可以嘗試再次下載。';
$lang->extension->errorTargetPathNotWritable   = '目標路徑 <strong>%s </strong>不可寫。';
$lang->extension->errorTargetPathNotExists     = '目標路徑 <strong>%s </strong>不存在。';
$lang->extension->errorInstallDB               = '執行資料庫語句失敗。錯誤信息如下：%s';
$lang->extension->errorConflicts               = '與插件“%s”衝突！';
$lang->extension->errorDepends                 = '以下依賴插件沒有安裝或版本不正確：<br /><br /> %s';
$lang->extension->errorIncompatible            = '該插件與您的禪道版本不兼容';
$lang->extension->errorUninstallDepends        = '插件“%s”依賴該插件，不能卸載';
$lang->extension->errorExtracted               = '包檔案 %s 解壓縮失敗，可能不是一個有效的zip檔案。錯誤信息如下：<br />%s';
$lang->extension->errorFileNotEmpty            = '上傳檔案不能為空';

==> ZenTaoPMS-ipd3.7-php7.0.zip: zentaopms/module/extension/lang/zh-tw.php <==
<?php
/**
 * The extension module zh-tw file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2023 禪道軟件（青島）有限公司(ZenTao Software (Qingdao) Co., Ltd. www.cnezsoft.com)
 * @license     ZPL(http://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Chunsheng Wang <chunsheng@cnezsoft.com>
 * @package     extension
 * @version     $Id$
 * @link        https://www.zentao.net
 */
$lang->extension->common           = '插件管理';
$lang->extension->id               = '編號';
$lang->extension->browse           = '瀏覽插件';
$lang->extension->install          = '安裝插件';
$lang->extension->installAuto      = '自動安裝';
$lang->extension->installForce     = '強制安裝';
$lang->extension->uninstall        = '卸載';
$lang->extension->uninstallAction  = '卸載插件';
$lang->extension->activate         = '激活';
$lang->extension->activateAction   = '激活插件';
$lang->extension->deactivate       = '禁用';
$lang->extension->deactivateAction = '禁用插件';
$lang->extension->obtain           = '獲得插件';
$lang->extension->view             = '詳情';
$lang->extension->downloadAB       = '下載';
$lang->extension->upload           = '本地安裝';
$lang->extension->erase            = '清除';
$lang->extension->eraseAction      = '清除插件';
$lang->extension->upgrade          = '升級插件';
$lang->extension->agreeLicense     = '我同意該授權';

$lang->extension->browseAction = '插件列表';

$lang->extension->structure       = '目錄結構';
$lang->extension->structureAction = '目錄結構';
$lang->extension->installed       = '已安裝';
$lang->extension->deactivated     = '被禁用';
$lang->extension->available       = '已下載';

$lang->extension->name             = '插件名稱';
$lang->extension->code             = '代號';
$lang->extension->desc             = '描述';
$lang->extension->type             = '類型';
$lang->extension->dirs             = '安裝目錄';
$lang->extension->files            = '安裝檔案';
$lang->extension->status           = '狀態';
$lang->extension->version          = '版本';
$lang->extension->latest           = '<small>最新版本<strong><a href="%s" target="_blank" class="extension">%s</a></strong>，兼容禪道<a href="https://api.zentao.net/goto.php?item=latest" target="_blank" class="alert-link"><strong>%s</strong></a></small>';
$lang->extension->author           = '作者';
$lang->extension->license          = '授權';
$lang->extension->site             = '官網';
$lang->extension->downloads        = '下載量';
$lang->extension->compatible       = '兼容性';
$lang->extension->grade            = '評分';
$lang->extension->depends          = '依賴';
$lang->extension->expiredDate      = '到期日期';
$lang->extension->zentaoCompatible = '適用版本';
$lang->extension->installedTime    = '安裝時間';
$lang->extension->life             = '終身';

$lang->extension->publicList[0] = '手工下載';
$lang->extension->publicList[1] = '直接下載';

$lang->extension->compatibleList[0] = '未知';
$lang->extension->compatibleList[1] = '兼容';

$lang->extension->obtainOfficial[0] = '第三方';
$lang->extension->obtainOfficial[1] = '官方';
$lang->extension->obtainOfficial[2] = '官方認證';

$lang->extension->byDownloads   = '最多下載';
$lang->extension->byAddedTime   = '最新添加';
$lang->extension->byUpdatedTime = '最近更新';
$lang->extension->bySearch      = '搜索';
$lang->extension->byCategory    = '分類瀏覽';

$lang->extension->featureBar['browse']['installed']   = $lang->extension->installed;
$lang->extension->featureBar['browse']['deactivated'] = $lang->extension->deactivated;
$lang->extension->featureBar['browse']['available']   = $lang->extension->available;

$lang->extension->installFailed            = '%s失敗，錯誤原因如下:';
$lang->extension->uninstallFailed          = '卸載失敗，錯誤原因如下:';
$lang->extension->confirmUninstall         = '卸載插件會刪除或修改相關的資料庫，是否繼續卸載？';
$lang->extension->installFinished          = '恭喜您，插件順利的%s成功！';
$lang->extension->refreshPage              = '刷新頁面';
$lang->extension->uninstallFinished        = '插件已經成功卸載';
$lang->extension->deactivateFinished       = '插件已經成功禁用';
$lang->extension->activateFinished         = '插件已經成功激活';
$lang->extension->eraseFinished            = '插件已經成功清除';
$lang->extension->unremovedFiles           = '有一些檔案或目錄未能刪除，需要手工刪除';
$lang->extension->executeCommands          = '<h3>執行下面的命令來修正這些問題：</h3>';
$lang->extension->successDownloadedPackage = '成功下載插件';
$lang->extension->successCopiedFiles       = '成功拷貝檔案';
$lang->extension->successInstallDB         = '成功安裝資料庫';
$lang->extension->viewInstalled            = '查看已安裝插件';
$lang->extension->viewAvailable            = '查看可安裝插件';
$lang->extension->viewDeactivated          = '查看已禁用插件';
$lang->extension->backDBFile               = '插件相關數據已經備份到 %s 檔案中！';
$lang->extension->noticeOkFile             = "<p class='font-bold mb-2'>為了安全起見，系統需要確認您的管理員身份</p>
    <p class='font-bold mb-2'>請登錄禪道所在的伺服器，創建%s檔案。</p>
    <p class='mb-2'>可以執行命令：echo '' > %s</p>
    <p class='mb-2'>注意：</p>
    <ul class='mb-2 pl-4' style='list-style: decimal'>
    <li>檔案內容為空。</li>
    <li>如果之前檔案存在，刪除之後重新創建。</li>
    </ul>";

$lang->extension->upgradeExt     = '升級';
$lang->extension->installExt     = '安裝';
$lang->extension->upgradeVersion = '（從%s升級到%s）';

$lang->extension->waring = '警告';

$lang->extension->errorOccurs                  = '錯誤：';
$lang->extension->errorGetModules              = '從www.zentao.net獲得插件分類失敗。可能是因為網絡方面的原因，請檢查後重新刷新頁面。';
$lang->extension->errorGetExtensions           = '從www.zentao.net獲得插件失敗。可能是因為網絡方面的原因，您可以到 <a href="https://www.zentao.net/extension/" target="_blank" class="alert-link">www.zentao.net</a> 手工下載插件，然後上傳安裝。';
$lang->extension->errorDownloadPathNotFound    = '插件下載存儲路徑<strong>%s</strong>不存在。<br />linux下面請執行命令：<strong>mkdir -p %s</strong>來修正。';
$lang->extension->errorDownloadPathNotWritable = '插件下載存儲路徑<strong>%s</strong>不可寫。<br />linux下面請執行命令：<strong>sudo chmod 777 %s</strong>來修正。';
$lang->extension->errorPackageFileExists       = '下載路徑已經有一個名為的<strong>%s</strong>附件。<strong>重新%s，<a href="%s" class="alert-link">請點擊此連結</a></strong>';
$lang->extension->errorDownloadFailed          = '下載失敗，請重新下載。如果多次重試還不行，請嘗試手工下載，然後通過上傳功能上傳。';
$lang->extension->errorMd5Checking             = '下載檔案不完整，請重新下載。如果多次重試還不行，請嘗試手工下載，然後通過上傳功能上傳。';
$lang->extension->errorCheckIncompatible       = '該插件與禪道版本不兼容，%s後可能無法使用。<strong>您可以選擇 <a href="#" load-url="%s" onclick="loadUrl(this)" class="btn size-sm">強制%s</a> 或者 <a href="#" load-url="%s" onclick="loadParentUrl(this)" class="btn size-sm">取消</a></strong>';
$lang->extension->errorFileConflicted          = '有以下檔案衝突：<br />%s <strong>您可以選擇 <a href="#" load-url="%s" onclick="loadUrl(this)" class="btn size-sm">覆蓋</a> 或者 <a href="#" load-url="%s" onclick="loadParentUrl(this)" class="btn size-sm">取消</a></strong>';
$lang->extension->errorPackageNotFound         = '包檔案 <strong>%s </strong>沒有找到，可能是因為自動下載失敗。您可以嘗試再次下載。';
$lang->extension->errorTargetPathNotWritable   = '目標路徑 <strong>%s </strong>不可寫。';
$lang->extension->errorTargetPathNotExists     = '目標路徑 <strong>%s </strong>不存在。';
$lang->extension->errorInstallDB               = '執行資料庫語句失敗。錯誤信息如下：%s';
$lang->extension->errorConflicts               = '與插件“%s”衝突！';
$lang->extension->errorDepends                 = '以下依賴插件沒有安裝或版本不正確：<br /><br /> %s';
$lang->extension->errorIncompatible            = '該插件與您的禪道版本不兼容';
$lang->extension->errorUninstallDepends        = '插件“%s”依賴該插件，不能卸載';
$lang->extension->errorExtracted               = '包檔案 %s 解壓縮失敗，可能不是一個有效的zip檔案。錯誤信息如下：<br />%s';
$lang->extension->errorFileNotEmpty            = '上傳檔案不能為空';
